Struct InodeLruNode
Source struct InodeLruNode {
inode_num: u32,
inode: Ext2Inode,
access_count: u64,
prev: Option<u32>,
next: Option<u32>,
}
Node in doubly-linked list for O(1) LRU operations for inodes
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.